# Braingeneers Python Utilities

[This package][github] is supposed to collect, as well as make installable
through Pip, all of the Python code and utilities that we develop as
part of the wetAI project.

[github]: https://www.github.com/braingeneers/wetai
